@@ -9,7 +9,7 @@ from .fstab import VolumesListing
 from .trash import (version, TrashDirReader, path_of_backup_copy, print_version,
                     maybe_parse_deletion_date, trash_dir_found,
                     trash_dir_skipped_because_parent_is_symlink,
-                    trash_dir_skipped_because_parent_not_sticky, UserInfoProvider, DirChecker)
+                    trash_dir_skipped_because_parent_not_sticky, UserInfoProvider, DirChecker, AllUsersInfoProvider)
 from .trash import TopTrashDirRules
 from .trash import TrashDirsScanner
 from .trash import ParseError
@@ -26,7 +26,7 @@ def main():
         environ=os.environ,
         getuid=os.getuid,
         volumes_listing=VolumesListing(os_mount_points),
-    ).run(*sys.argv)
+    ).run(sys.argv)
 
 
 class ListCmd:
@@ -46,18 +46,13 @@ class ListCmd:
         self.version = version
         self.file_reader = file_reader
         self.environ = environ
-        self.volume_listing = volumes_listing  # type: VolumesListing
-        user_info_provider = UserInfoProvider(self.environ, getuid)
-        trashdirs_scanner = TrashDirsScanner(user_info_provider,
-                                             self.volume_listing,
-                                             TopTrashDirRules(file_reader),
-                                             DirChecker())
-        self.selector = TrashDirsSelector(
-            trashdirs_scanner.scan_trash_dirs(self.environ),
-            [],
-            volume_of)
+        self.uid = getuid()
+        self.volumes_listing = volumes_listing
+        self.selector = TrashDirsSelector.make(volumes_listing,
+                                               file_reader,
+                                               volume_of)
 
-    def run(self, *argv):
+    def run(self, argv):
         parser = Parser(os.path.basename(argv[0]))
         parsed = parser.parse_list_args(argv[1:])
         if parsed.action == Action.print_version:
@@ -66,12 +61,22 @@ class ListCmd:
             self.print_volumes_list()
         elif parsed.action == Action.debug_volumes:
             self.debug_volumes()
+        elif parsed.action == Action.list_trash_dirs:
+            self.list_trash_dirs(parsed.trash_dirs,
+                                 parsed.all_users,
+                                 self.environ,
+                                 self.uid)
         elif parsed.action == Action.list_trash:
             extractor = {
                 'deletion_date': DeletionDateExtractor(),
                 'size': SizeExtractor(),
             }[parsed.attribute_to_print]
-            self.list_trash(parsed.trash_dirs, extractor, parsed.show_files)
+            self.list_trash(parsed.trash_dirs,
+                            extractor,
+                            parsed.show_files,
+                            parsed.all_users,
+                            self.environ,
+                            self.uid)
         else:
             raise ValueError('Unknown action: ' + parsed.action)
 
@@ -88,9 +93,17 @@ class ListCmd:
         pprint(virtual)
         os.system('df -P')
 
-    def list_trash(self, user_specified_trash_dirs, extractor, show_files):
-        trash_dirs = self.selector.select(False,
-                                          user_specified_trash_dirs)
+    def list_trash(self,
+                   user_specified_trash_dirs,
+                   extractor,
+                   show_files,
+                   all_users,
+                   environ,
+                   uid):
+        trash_dirs = self.selector.select(all_users,
+                                          user_specified_trash_dirs,
+                                          environ,
+                                          uid)
         for event, args in trash_dirs:
             if event == trash_dir_found:
                 path, volume = args
@@ -104,6 +117,27 @@ class ListCmd:
                 path, = args
                 self.output.top_trashdir_skipped_because_parent_is_symlink(path)
 
+    def list_trash_dirs(self,
+                        user_specified_trash_dirs,
+                        all_users,
+                        environ,
+                        uid):
+        trash_dirs = self.selector.select(all_users,
+                                          user_specified_trash_dirs,
+                                          environ,
+                                          uid)
+        for event, args in trash_dirs:
+            pprint(args)
+            if event == trash_dir_found:
+                path, volume = args
+                print("%s, %s" % (path, volume))
+            elif event == trash_dir_skipped_because_parent_not_sticky:
+                path = args
+                print("parent_not_sticky: %s" % (path))
+            elif event == trash_dir_skipped_because_parent_is_symlink:
+                path = args
+                print("parent_is_symlink: %s" % (path))
+
     def _print_trashinfo(self, volume, trashinfo_path, extractor, show_files):
         try:
             contents = self.file_reader.contents_of(trashinfo_path)
@@ -126,7 +160,7 @@ class ListCmd:
                 self.output.println(line)
 
     def print_volumes_list(self):
-        for volume in self.volume_listing.list_volumes(self.environ):
+        for volume in self.volumes_listing.list_volumes(self.environ):
             print(volume)
 
 
@@ -170,17 +204,37 @@ class TrashDirsSelector:
         self.all_users_dirs = all_users_dirs
         self.volume_of = volume_of
 
-    def select(self, all_users_flag, user_specified_dirs):
+    def select(self,
+               all_users_flag,
+               user_specified_dirs,
+               environ,
+               uid):
         if all_users_flag:
-            for dir in self.all_users_dirs:
+            for dir in self.all_users_dirs.scan_trash_dirs(environ, uid):
                 yield dir
         else:
             if not user_specified_dirs:
-                for dir in self.current_user_dirs:
+                for dir in self.current_user_dirs.scan_trash_dirs(environ, uid):
                     yield dir
             for dir in user_specified_dirs:
                 yield trash_dir_found, (dir, self.volume_of(dir))
 
+    @staticmethod
+    def make(volumes_listing, file_reader, volume_of):
+        user_info_provider = UserInfoProvider()
+        user_dir_scanner = TrashDirsScanner(user_info_provider,
+                                            volumes_listing,
+                                            TopTrashDirRules(file_reader),
+                                            DirChecker())
+        all_users_info_provider = AllUsersInfoProvider()
+        all_users_scanner = TrashDirsScanner(all_users_info_provider,
+                                             volumes_listing,
+                                             TopTrashDirRules(file_reader),
+                                             DirChecker())
+        return TrashDirsSelector(user_dir_scanner,
+                                 all_users_scanner,
+                                 volume_of)
+
 
 class SuperEnum(object):
     class __metaclass__(type):
@@ -195,6 +249,7 @@ class Action(SuperEnum):
     print_version = 'print_version'
     list_trash = 'list_trash'
     list_volumes = 'list_volumes'
+    list_trash_dirs = 'list_trash_dirs'
 
 
 class Parser:
@@ -218,6 +273,11 @@ class Parser:
                                  action='store_const',
                                  const=Action.list_volumes,
                                  help="list volumes")
+        self.parser.add_argument('--trash-dirs',
+                                 dest='action',
+                                 action='store_const',
+                                 const=Action.list_trash_dirs,
+                                 help="list trash dirs")
         self.parser.add_argument('--trash-dir',
                                  action='append',
                                  default=[],
@@ -234,6 +294,10 @@ class Parser:
                                  default=False,
                                  dest='show_files',
                                  help=argparse.SUPPRESS)
+        self.parser.add_argument('--all-users',
+                                 action='store_true',
+                                 dest='all_users',
+                                 help='list trashcans of all the users')
 
     def parse_list_args(self, args):
         parsed = self.parser.parse_args(args)
